@@ -33,7 +33,8 @@ public:
     void askRemoveTab(int index);
 
 protected slots:
-    void onCurrentChanged(int index);
+    void onCurrentTabChanged(int index);
+    void onCurrentTextModified(bool modified);
 
 private:
     QList<EditWidget*> editwidgetlist;
