@@ -53,6 +53,7 @@ ScoreMenu::ScoreMenu(QWidget* parent)
 #else
     addAction(tr("Save"), QKeySequence::Save, this, SLOT(onSaveActionTriggered()));
     addAction(tr("Save as"), QKeySequence::SaveAs, this, SLOT(onSaveAsActionTriggered()));
+    addAction(tr("Export to MIDI"), this, SLOT(onExportMIDIActionTriggered()));
     addAction(tr("Close"), QKeySequence::Close, this, SLOT(onCloseActionTriggered()));
     addAction(tr("Quit"), QKeySequence::Quit, this, SLOT(onQuitActionTriggered()));
 #endif
@@ -239,6 +240,29 @@ void ScoreMenu::onSaveAsActionTriggered()
     return onSaveActionTriggered();
 }
 
+void ScoreMenu::onExportMIDIActionTriggered()
+{
+    AbcApplication* a = static_cast<AbcApplication*>(qApp);
+    AbcMainWindow* w = a->mainWindow();
+    EditTabWidget *edittabs = w->mainHBoxLayout()->editTabWidget();
+    int cur = edittabs->currentIndex();
+    if (cur < 0)
+        return;
+
+    QString suggestion = edittabs->tabText(cur).append(".mid");
+    //QString  home = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+    QString fileName = QFileDialog::getSaveFileName(this, tr("Export to MIDI"), suggestion, tr("MIDI file (*.mid)"));
+    if (fileName.isEmpty())
+        return; /* cancelled */
+
+    if (!fileName.endsWith(".mid"))
+        fileName.append(".mid");
+
+    EditVBoxLayout* scoreEdit =  a->mainWindow()->mainHBoxLayout()->editTabWidget()->currentEditWidget()->editVBoxLayout();
+    emit scoreEdit->doExportMIDI(fileName);
+
+}
+
 void ScoreMenu::onCloseActionTriggered()
 {
     AbcApplication* a = static_cast<AbcApplication*>(qApp);
